### This script checks only conjugacy classes
### with representatives of order 28 or 35
LoadPackage("atlasrep");
LoadPackage("io");

checkD_random := function(gr, x, n)
  local sg, i, t, y;
  Print("Trying with n=", n, "\n");
  for i in [1..n] do
    t := Random(gr);
    y := t*x*Inverse(t);
    if not (x*y)^2 = (y*x)^2 then 
      sg := Subgroup(gr, [x,y]);
      if IsConjugate(sg, x, y) = false then
        return [x,y];
      fi;
    fi;
  od;
  return fail;
end;

x := [];
g := [];
n := 0;

name := "A6xU3(3)";
LogTo(Concatenation(name, ".log"));

gr := DirectProduct(AlternatingGroup(6), PSU(3,3)); 
cc := ConjugacyClasses(gr);

bg := BaseOfGroup(gr);
Print("Base of Group: ", bg, "\n");

f := IO_File(Concatenation(name, ".rec"), "w");
IO_WriteLine(f,"### The format for classinfo is [ r, s, order, comment ]");
IO_WriteLine(f,"data := rec(");
IO_WriteLine(f,"  base := ", bg, ",");
IO_WriteLine(f,"  group := \"A6xU3(3)\",");
IO_WriteLine(f,"  comments := \"Randon with N=10000\",");
IO_WriteLine(f,"  classinfo := [");

for c in cc do
  g := Representative(c);
  if Order(g) in [28, 35] then
    Print("Checking conjugacy class with representative of order: ", Order(g), "\n");
    rs := checkD_random(gr, g, 10000); 
    if not rs = fail then
      Print("r:=", OnTuples(bg, rs[1]), ";\n");
      Print("s:=", OnTuples(bg, rs[2]), ";\n");
      IO_WriteLine(f, "    [ ", OnTuples(bg, rs[1]), ", ", OnTuples(bg, rs[2]), ", ", Order(g), ", \"D\" ],");
    else
      Print("Size of the conjugacy class: ", Size(c), "\n");
      Print("Fail!\n");
      IO_WriteLine(f, "    [ fail, ",OnTuples(bg, g), ", ", Order(g), ", \"class of size ", Size(c), "\" ],");
    fi;
    Print("--\n");
  fi;
od;
IO_WriteLine(f, "  []");
IO_WriteLine(f, "  ]");
IO_WriteLine(f, ");");
IO_Flush(f);
IO_Close(f);


