LoadPackage("atlasrep");
LoadPackage("io");

groupname := "B";
subgroup := "47:23";

LogTo("step8.log");

Print("Fusion of conjugacy classes from ", subgroup, " into ", groupname, "\n");

ct1 := CharacterTable(groupname);
ct2 := CharacterTable(subgroup);

fus := FusionConjugacyClasses(ct2, ct1);
if not fus = fail then
  for t in [1..Size(fus)] do
    Print(ClassNames(ct2)[t], " --> ", ClassNames(ct1)[fus[t]], "\n");
  od;
else
  for fus in PossibleClassFusions(ct2, ct1) do
    for t in [1..Size(fus)] do
      Print(ClassNames(ct2)[t], " --> ", ClassNames(ct1)[fus[t]], ";\n");
    od;
    Print("--\n");
  od;
fi;

check := function(group, c, d)
  local r, s;
  r := Representative(c);
  for s in d do
    if (r*s)^2 <> (s*r)^2 then
      return [r,s];
    fi;
  od;
  return fail;
end;
   
xx := Image(IsomorphismPermGroup(SmallGroup(47*23,1)));
gr := Image(SmallerDegreePermutationRepresentation(xx));
cc := ConjugacyClasses(gr);

bg := BaseOfGroup(gr);
Print("Base of Group: ", bg, "\n");

str := [];
gen := GeneratorsOfGroup(gr);
for t in gen do
  Add(str, t);
od;

f := IO_File("step8.rec", "w");
IO_WriteLine(f,"### The format for classinfo is [ r, s, order, comment ]");
IO_WriteLine(f,"data := rec(");
IO_WriteLine(f,"  base := ", bg, ",");
IO_WriteLine(f,"  group := \"47:23\",");
IO_WriteLine(f,"  gens := \"", str, "\",");
IO_WriteLine(f,"  comments := \"For classes with representatives of order 23\",");
IO_WriteLine(f,"  classinfo := [");

Print("Connecting group and character table: ", ConnectGroupAndCharacterTable(gr, ct2), "\n");

Print("Conjugacy classes 23A, 23D of this maximal subgroup:\n");
i := IdentificationOfConjugacyClasses(ct2)[ct2.23a];
j := IdentificationOfConjugacyClasses(ct2)[ct2.23d];
rs := check(gr, cc[i], cc[j]);
Print("r:=", OnTuples(bg, rs[1]), "\n");
Print("s:=", OnTuples(bg, rs[2]), "\n");
IO_WriteLine(f, "    [ ", OnTuples(bg, rs[1]), ", ", OnTuples(bg, rs[2]), ", 23, \"classes 23a and 23d\" ],");

Print("Conjugacy classes 23u, 23v of this maximal subgroup:\n");
i := IdentificationOfConjugacyClasses(ct2)[ct2.23u];
j := IdentificationOfConjugacyClasses(ct2)[ct2.23v];
rs := check(gr, cc[i], cc[j]);
Print("r:=", OnTuples(bg, rs[1]), "\n");
Print("s:=", OnTuples(bg, rs[2]), "\n");
IO_WriteLine(f, "    [ ", OnTuples(bg, rs[1]), ", ", OnTuples(bg, rs[2]), ", 23, \"classes 23u and 23v\" ]");
IO_WriteLine(f, "  ]");
IO_WriteLine(f, ");");
IO_Flush(f);
IO_Close(f);

