LoadPackage("io");

checkD := function(gr, c)
  local sg, x, y;
  x := Representative(c);
  for y in c do
    if not (x*y)^2 = (y*x)^2 then 
      sg := Subgroup(gr, [x,y]);
      if IsConjugate(sg, x, y) = false then
        return [x,y];
      fi;
    fi;
  od;
  return fail;
end;

#
# www-ATLAS of Group Representations
#
max := function()
local result, i, m, d;
result := rec();

result.comment := "L2(29):2 represented as permutations on 30 points.\n";

result.generators := [
[3,5,1,8,2,11,12,4,15,13,6,7,10,19,9,18,23,16,14,21,20,25,17,27,
22,28,24,26,30,29]
,
[2,4,6,7,9,10,8,13,14,16,12,15,17,18,20,21,22,19,23,24,25,26,27,
3,28,11,29,5,1,30]
];
for i in [1..Length(result.generators)] do
  m := Minimum( result.generators[i] );
  d := m - 1;
  Apply( result.generators[i], j -> j-d);
  result.generators[i] := PermList(result.generators[i]);
od;
return result;
end;

LogTo("step4.log");

gr := Group(max().generators);
ct := CharacterTable(gr);
cc := ConjugacyClasses(gr);

bg := BaseOfGroup(gr);
Print("Base of Group: ", bg, "\n");

f := IO_File("step4.rec", "w");
IO_WriteLine(f,"### The format for classinfo is [ r, s, order, comment ]");
IO_WriteLine(f,"data := rec(");
IO_WriteLine(f,"  base := ", bg, ",");
IO_WriteLine(f,"  group := \"L2(29):2\",");
IO_WriteLine(f,"  comments := \"For classes with representatives of order 29\",");
IO_WriteLine(f,"  classinfo := [");


for c in cc do
  g := Representative(c);
  if Order(g) = 29 then
    Print("Checking a conjugacy class with representative of order ", Order(g), "\n");
    rs := checkD(gr, c); 
    if not rs = fail then
      Print("r:=", OnTuples(bg, rs[1]), ";\n");
      Print("s:=", OnTuples(bg, rs[2]), ";\n");
      IO_WriteLine(f, "    [ ", OnTuples(bg, rs[1]), ", ", OnTuples(bg, rs[2]), ", ", Order(g), ", \"D\" ],");
    else
      Print("Size of the conjugacy class: ", Size(c), "\n");
      Print("Fail!\n");
      IO_WriteLine(f, "    [ fail, ", OnTuples(bg, g), ", ", Order(g), ", \"class of size ", Size(c), "\" ],");
    fi;
  fi;
od;

IO_WriteLine(f, "    [ fail, (), 1, \"one\"]");
IO_WriteLine(f, "  ]");
IO_WriteLine(f, ");");
IO_Flush(f);
IO_Close(f);


