LoadPackage("atlasrep");
LoadPackage("io");

groupname := "M";
subgroup := "2x47:23";

LogTo("step9.log");

Print("Fusion of conjugacy classes from ", subgroup, " into ", groupname, "\n");

ct1 := CharacterTable(groupname);
ct2 := CharacterTable(subgroup);

fus := FusionConjugacyClasses(ct2, ct1);
if not fus = fail then
  for t in [1..Size(fus)] do
    Print(ClassNames(ct2)[t], " --> ", ClassNames(ct1)[fus[t]], "\n");
  od;
else
  for fus in PossibleClassFusions(ct2, ct1) do
    for t in [1..Size(fus)] do
      Print(ClassNames(ct2)[t], " --> ", ClassNames(ct1)[fus[t]], ";\n");
    od;
    Print("--\n");
  od;
fi;

check := function(group, c, d)
  local r, s;
  r := Representative(c);
  for s in d do
    if (r*s)^2 <> (s*r)^2 then
      return [r,s];
    fi;
  od;
  return fail;
end;
   
gr := Image(IsomorphismPermGroup(DirectProduct(SymmetricGroup(2), SmallGroup(47*23,1))));
cc := ConjugacyClasses(gr);

bg := BaseOfGroup(gr);
Print("Base of Group: ", bg, "\n");

str := [];
gen := GeneratorsOfGroup(gr);
for t in gen do
  Add(str,  t);
od;

f := IO_File("step9.rec", "w");
IO_WriteLine(f,"### The format for classinfo is [ r, s, order, comment ]");
IO_WriteLine(f,"data := rec(");
IO_WriteLine(f,"  base := ", bg, ",");
IO_WriteLine(f,"  group := \"2x47:23\",");
IO_WriteLine(f,"  gens := \"", str, "\",");
IO_WriteLine(f,"  comments := \"For classes with representatives of order 46\",");
IO_WriteLine(f,"  classinfo := [");

Print("Connecting group and character table: ", ConnectGroupAndCharacterTable(gr, ct2), "\n");

Print("Conjugacy classes 46A, 46B of this maximal subgroup:\n");
i := IdentificationOfConjugacyClasses(ct2)[ct2.46a];
j := IdentificationOfConjugacyClasses(ct2)[ct2.46b];
rs := check(gr, cc[i], cc[j]);
if rs <> fail then
  Print("r:=", OnTuples(bg, rs[1]), "\n");
  Print("s:=", OnTuples(bg, rs[2]), "\n");
  IO_WriteLine(f, "    [ ", OnTuples(bg, rs[1]), ", ", OnTuples(bg, rs[2]), ", 46, \"classes 46A and 46B\" ],");
fi;

Print("Conjugacy classes 46N, 46O of this maximal subgroup:\n");
i := IdentificationOfConjugacyClasses(ct2)[ct2.46n];
j := IdentificationOfConjugacyClasses(ct2)[ct2.46o];
rs := check(gr, cc[i], cc[j]);
if rs <> fail then
  Print("r:=", OnTuples(bg, rs[1]), ";\n");
  Print("s:=", OnTuples(bg, rs[2]), ";\n");
  IO_WriteLine(f, "    [ ", OnTuples(bg, rs[1]), ", ", OnTuples(bg, rs[2]), ", 46, \"classes 46N and 46O\" ]");
fi;
IO_WriteLine(f, "  ]");
IO_WriteLine(f, ");");
IO_Flush(f);
IO_Close(f);

