### FUNCTION QuasiReal
### 
### Returns quasi-real (and not real) conjugacy classes 
### and the how many non-trivial powers belongs to the class
###
### returns: [a,b], where
###     a := quasi-real conjugacy classes with g^(j^2) = g
###     b := quasi-real conjugacy classes with g^(j^2) <> g
###
### Written by Fernando Fantino and Leandro Vendramin 

QuasiRealClasses := function( ct )
  local nc, oc, a, b, p, c, j, rc;

  nc := NrConjugacyClasses(ct); 
  oc := OrdersClassRepresentatives(ct);
  rc := RealClasses(ct);

  a := [];
  b := [];

  for c in [1..nc] do
    if not c in rc then
      for j in [2..oc[c]-2] do
        p := PowerMap(ct, j);
        if p[c] = c then
          if j-1 mod oc[c] <> 0 then
            if not c in b then
              Add(a, [c, j]);
              Add(b, c);
            fi;
          fi;
        fi; 
      od;
    fi;
  od;
  return a;
end;

LoadPackage("atlasrep");
LogTo("appendix.log");

for name in Union(["L5(2)", "O7(3)", "O8+(2)", "O10-(2)", "G2(4)", "G2(3)", "G2(5)", "S6(2)", "S8(2)", "2F4(2)'"], 
          AllCharacterTableNames(IsSporadicSimple, true)) do 

  ct := CharacterTable(name);
  Print("Group: ", name, "\n");
  Print("Order: ", Size(ct), "\n");
  Print("Conjugacy classes: ", NrConjugacyClasses(ct), "\n");
  if HasMaxes(ct) = true then
    Print("Maximal subgroups: ", Size(Maxes(ct)), "\n");
  else
    Print("The information about maximal subgroups is missing!\n");
  fi;

  rc := RealClasses(ct);
  Print("Real Classes:\n");
  for i in rc do
    Print(ClassNames(ct)[i], ", centralizer of order ", SizesCentralizers(ct)[i], "\n");
  od;

  qc := QuasiRealClasses(ct);
  Print("--\nQuasi-real Classes:\n");
  for i in qc do
    Print(ClassNames(ct)[i[1]], " of type ", i[2], ", centralizer of size ", SizesCentralizers(ct)[i[1]], "\n");
  od;
 
  Print("--\nNot real, not quasi-real:\n");
  for i in [1..NrConjugacyClasses(ct)] do
    if not i in rc and not i in List(qc, x->x[1]) then
      Print(ClassNames(ct)[i], ", centralizer of size ", SizesCentralizers(ct)[i], "\n");
    fi;
  od;
  Print("==\n");
od;


